@@ -3,7 +3,6 @@ import os
 
 class IsPycharmRun:
     def __init__(self, deviceUrl, logDir):
-        self.confManager = self.loadConfig()
         self.deviceUrl = deviceUrl
         self.logDir = logDir
 
@@ -12,7 +11,6 @@ class IsPycharmRun:
         def wrapped_function(baseDir):
             if self.isPycharmRun():
                 print(func.__name__ + " was called")
-                self.genAutoSetupArgv()
                 return func(basedir=baseDir, devices=self.deviceUrl, logdir=self.logDir)
             else:
                 print("非pycharm环境，正常调试模式")
